@@ -11,9 +11,13 @@ def callback():
     """
 
 
-@app.command()
-def common():
-    typer.echo("Hi mate!")
+@app.command(upper: bool = typer.Option(False, help="Is uppercase."),
+def common():         
+    if upper:
+        text = "HI MATE!" 
+    else:
+        text = "Hi mate!" 
+    typer.echo(text)
 
 
 @app.command()
